@@ -44,9 +44,9 @@ import Germinate.version
 
 
 # Where do we get up-to-date seeds from?
-SEEDS = ["http://people.ubuntu.com/~ubuntu-archive/seeds/"]
+SEEDS = ["http://people.canonical.com/~ubuntu-archive/seeds/"]
 SEEDS_BZR = ["http://bazaar.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/"]
-RELEASE = "ubuntu.jaunty"
+RELEASE = "ubuntu.karmic"
 
 # If we need to download Packages.gz and/or Sources.gz, where do we get
 # them from?
@@ -54,7 +54,7 @@ MIRRORS = []
 SOURCE_MIRRORS = []
 DEFAULT_MIRROR = "http://archive.ubuntu.com/ubuntu/"
 DEFAULT_SOURCE_MIRROR = None
-DIST = ["jaunty"]
+DIST = ["karmic"]
 COMPONENTS = ["main", "restricted"]
 ARCH = "i386"
 
