@@ -33,10 +33,10 @@ import Germinate.seeds
 import Germinate.version
 
 # TODO: cloned from germinate.py; should be common
-SEEDS = ["http://people.ubuntu.com/~ubuntu-archive/seeds/"]
-RELEASE = "ubuntu.jaunty"
+SEEDS = ["http://people.canonical.com/~ubuntu-archive/seeds/"]
+RELEASE = "ubuntu.karmic"
 MIRRORS = ["http://archive.ubuntu.com/ubuntu/"]
-DIST = ["jaunty"]
+DIST = ["karmic"]
 COMPONENTS = ["main"]
 ARCH = "i386"
 
